@@ -179,7 +179,7 @@ class CommunitiesMixin:
         photo=None,
         facet_value=None,
     ):
-        """Create a new community.
+        """Modify a community.
 
         :param project_id: Project identifier
         :param community_type_id: Community type identifier
@@ -192,7 +192,7 @@ class CommunitiesMixin:
 
         Example::
 
-            >>> client.create_community(project_id='BFXfzPHKQP2xRxAP86Kfig',
+            >>> client.modify_community(project_id='BFXfzPHKQP2xRxAP86Kfig',
             ...                      community_type_id='G0Tm2SQcTqu2d4GvfyrsMg',
             ...                      community_id='yX-D0_oqRgSrCFoTjhmbJg',
             ...                      name='Marcus',
@@ -257,3 +257,44 @@ class CommunitiesMixin:
         }
         res = self._perform_request("delete", url)
         return self._process_response(res, [204])
+
+    def get_community_followers(self, project_id, community_type_id, community_id):
+        """Return the user details of users subscribed to the community with
+        given `community_id`.
+
+        :param project_id: Project identifier
+        :param community_type_id: Community type identifier
+        :param community_id: Community identifier
+
+        :returns: A list of dictionaries with user details.
+
+        Example::
+
+            >>> client.get_community_followers('BFXfzPHKQP2xRxAP86Kfig',
+            ...                      'G0Tm2SQcTqu2d4GvfyrsMg',
+            ...                      'yX-D0_oqRgSrCFoTjhmbJg')
+            [
+                {u'full_name': u'Marcus Rashford',
+                u'email': u'rashford@mufc.com',
+                },
+                .
+                .
+                .
+                {u'full_name': u'David De Gea',
+                u'email': u'degea@mufc.com',
+                }
+            ]
+        """
+
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
+            "community_types/%(community_type_id)s/communities/%(community_id)s/followers"
+        ) % {
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "community_type_id": community_type_id,
+            "community_id": community_id,
+        }
+        res = self._perform_request("get", url)
+        return self._process_response(res)
