@@ -4,7 +4,7 @@ import logging
 log = logging.getLogger(__name__)
 
 
-class CommunityTypesMixin(object):
+class CommunityTypesMixin:
     def get_community_types(self, project_id):
         """Returns all community types for a particular project.
 
@@ -33,11 +33,11 @@ class CommunityTypesMixin(object):
             ]
         """
 
-        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/community_types" % {
-            "ep": self.topic_api_url,
-            "tenant": self.tenant,
-            "project_id": project_id,
-        }
+        url = "{ep}/v0/{tenant}/projects/{project_id}/community_types".format(
+            ep=self.topic_api_url,
+            tenant=self.tenant,
+            project_id=project_id,
+        )
         res = self._perform_request("get", url)
         return self._process_response(res)
 
@@ -185,6 +185,38 @@ class CommunityTypesMixin(object):
         res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
         return self._process_response(res)
 
+    def move_community_type(self, project_id, community_type_id, after):
+        """Move a community type.
+
+        :param project_id: Project identifier
+        :param community_type_id: Community type identifier
+        :param after: The community type identifier after which the community
+            type should be moved. Can be `None` to move the community type to
+            the beginning of the list.
+
+        :returns: No return value.
+
+        Example::
+
+            >>> client.move_community_type('Xh9CeyQtTYe2cv5F11e6nQ',
+            ...                            'LB5Q-GmBSbaNvJhUxXfUaA',
+            ...                            'AaUfXUhJvNabSBBmG-Q5LB')
+        """
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
+            "community_types/%(community_type_id)s/move"
+        ) % {
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "community_type_id": community_type_id,
+        }
+        headers = {"Content-Type": "application/json"}
+        res = self._perform_request(
+            "post", url, data=json.dumps({"after": after}), headers=headers
+        )
+        return self._process_response(res, [204])
+
     def delete_community_type(self, project_id, community_type_id):
         """Deletes a community type
 
